summaryrefslogtreecommitdiffstats
path: root/ui
diff options
context:
space:
mode:
Diffstat (limited to 'ui')
-rw-r--r--ui/aura/client/dispatcher_client.h4
-rw-r--r--ui/aura/dispatcher_win.cc8
-rw-r--r--ui/aura/env.cc2
-rw-r--r--ui/aura/env.h8
-rw-r--r--ui/aura/root_window_host_ozone.h4
-rw-r--r--ui/aura/root_window_host_x11.h4
-rw-r--r--ui/events/ozone/evdev/touch_event_converter_unittest.cc4
-rw-r--r--ui/views/controls/menu/menu_controller.cc2
-rw-r--r--ui/views/controls/menu/menu_controller.h4
-rw-r--r--ui/views/focus/accelerator_handler.h5
-rw-r--r--ui/views/widget/desktop_aura/desktop_dispatcher_client.cc2
-rw-r--r--ui/views/widget/desktop_aura/desktop_dispatcher_client.h2
-rw-r--r--ui/views/widget/desktop_aura/desktop_drag_drop_client_aurax11.cc5
-rw-r--r--ui/views/widget/desktop_aura/desktop_root_window_host_x11.cc2
-rw-r--r--ui/views/widget/desktop_aura/desktop_root_window_host_x11.h2
-rw-r--r--ui/views/widget/desktop_aura/x11_desktop_handler.h6
-rw-r--r--ui/views/widget/desktop_aura/x11_whole_screen_move_loop.cc2
-rw-r--r--ui/views/widget/desktop_aura/x11_whole_screen_move_loop.h7
18 files changed, 38 insertions, 35 deletions
diff --git a/ui/aura/client/dispatcher_client.h b/ui/aura/client/dispatcher_client.h
index f2d1ff8..8e5e1ec 100644
--- a/ui/aura/client/dispatcher_client.h
+++ b/ui/aura/client/dispatcher_client.h
@@ -5,7 +5,7 @@
#ifndef UI_AURA_CLIENT_DISPATCHER_CLIENT_H_
#define UI_AURA_CLIENT_DISPATCHER_CLIENT_H_
-#include "base/message_loop/message_loop.h"
+#include "base/message_loop/message_pump_dispatcher.h"
#include "ui/aura/aura_export.h"
#include "ui/aura/window.h"
@@ -16,7 +16,7 @@ namespace client {
// An interface implemented by an object which handles nested dispatchers.
class AURA_EXPORT DispatcherClient {
public:
- virtual void RunWithDispatcher(base::MessageLoop::Dispatcher* dispatcher,
+ virtual void RunWithDispatcher(base::MessagePumpDispatcher* dispatcher,
aura::Window* associated_window,
bool nestable_tasks_allowed) = 0;
};
diff --git a/ui/aura/env.cc b/ui/aura/env.cc
index 4640b85..cd98057 100644
--- a/ui/aura/env.cc
+++ b/ui/aura/env.cc
@@ -76,7 +76,7 @@ bool Env::IsMouseButtonDown() const {
mouse_button_flags_ != 0;
}
-base::MessageLoop::Dispatcher* Env::GetDispatcher() {
+base::MessagePumpDispatcher* Env::GetDispatcher() {
#if defined(USE_X11)
return base::MessagePumpX11::Current();
#else
diff --git a/ui/aura/env.h b/ui/aura/env.h
index 00e5ce21..9e3e7aa 100644
--- a/ui/aura/env.h
+++ b/ui/aura/env.h
@@ -6,7 +6,7 @@
#define UI_AURA_ENV_H_
#include "base/memory/scoped_ptr.h"
-#include "base/message_loop/message_loop.h"
+#include "base/message_loop/message_pump_dispatcher.h"
#include "base/observer_list.h"
#include "ui/aura/aura_export.h"
#include "ui/events/event_handler.h"
@@ -29,7 +29,7 @@ class RootWindow;
class Window;
// Creates a platform-specific native event dispatcher.
-base::MessageLoop::Dispatcher* CreateDispatcher();
+base::MessagePumpDispatcher* CreateDispatcher();
// A singleton object that tracks general state within Aura.
// TODO(beng): manage RootWindows.
@@ -66,7 +66,7 @@ class AURA_EXPORT Env : public ui::EventTarget {
// Returns the native event dispatcher. The result should only be passed to
// base::RunLoop(dispatcher), or used to dispatch an event by
// |Dispatch(const NativeEvent&)| on it. It must never be stored.
- base::MessageLoop::Dispatcher* GetDispatcher();
+ base::MessagePumpDispatcher* GetDispatcher();
// Invoked by RootWindow when its host is activated.
void RootWindowActivated(RootWindow* root_window);
@@ -91,7 +91,7 @@ class AURA_EXPORT Env : public ui::EventTarget {
virtual ui::EventTargeter* GetEventTargeter() OVERRIDE;
ObserverList<EnvObserver> observers_;
- scoped_ptr<base::MessageLoop::Dispatcher> dispatcher_;
+ scoped_ptr<base::MessagePumpDispatcher> dispatcher_;
static Env* instance_;
int mouse_button_flags_;
diff --git a/ui/aura/root_window_host_ozone.h b/ui/aura/root_window_host_ozone.h
index a026994..aac148c 100644
--- a/ui/aura/root_window_host_ozone.h
+++ b/ui/aura/root_window_host_ozone.h
@@ -8,7 +8,7 @@
#include <vector>
#include "base/memory/scoped_ptr.h"
-#include "base/message_loop/message_loop.h"
+#include "base/message_loop/message_pump_dispatcher.h"
#include "ui/aura/window_tree_host.h"
#include "ui/gfx/insets.h"
#include "ui/gfx/rect.h"
@@ -16,7 +16,7 @@
namespace aura {
class WindowTreeHostOzone : public WindowTreeHost,
- public base::MessageLoop::Dispatcher {
+ public base::MessagePumpDispatcher {
public:
explicit WindowTreeHostOzone(const gfx::Rect& bounds);
virtual ~WindowTreeHostOzone();
diff --git a/ui/aura/root_window_host_x11.h b/ui/aura/root_window_host_x11.h
index ece9642..0504169 100644
--- a/ui/aura/root_window_host_x11.h
+++ b/ui/aura/root_window_host_x11.h
@@ -13,7 +13,7 @@
#undef RootWindow
#include "base/memory/scoped_ptr.h"
-#include "base/message_loop/message_loop.h"
+#include "base/message_loop/message_pump_dispatcher.h"
#include "ui/aura/aura_export.h"
#include "ui/aura/env_observer.h"
#include "ui/aura/window_tree_host.h"
@@ -34,7 +34,7 @@ class TouchEventCalibrate;
}
class AURA_EXPORT WindowTreeHostX11 : public WindowTreeHost,
- public base::MessageLoop::Dispatcher,
+ public base::MessagePumpDispatcher,
public ui::EventSource,
public EnvObserver {
public:
diff --git a/ui/events/ozone/evdev/touch_event_converter_unittest.cc b/ui/events/ozone/evdev/touch_event_converter_unittest.cc
index b5d6847..e1eddaa 100644
--- a/ui/events/ozone/evdev/touch_event_converter_unittest.cc
+++ b/ui/events/ozone/evdev/touch_event_converter_unittest.cc
@@ -11,7 +11,7 @@
#include "base/memory/scoped_ptr.h"
#include "base/memory/scoped_vector.h"
-#include "base/message_loop/message_loop.h"
+#include "base/message_loop/message_pump_dispatcher.h"
#include "base/posix/eintr_wrapper.h"
#include "base/run_loop.h"
#include "base/time/time.h"
@@ -33,7 +33,7 @@ static int SetNonBlocking(int fd) {
namespace ui {
class MockTouchEventConverterEvdev : public TouchEventConverterEvdev,
- public base::MessageLoop::Dispatcher {
+ public base::MessagePumpDispatcher {
public:
MockTouchEventConverterEvdev(int a, int b);
virtual ~MockTouchEventConverterEvdev() {};
diff --git a/ui/views/controls/menu/menu_controller.cc b/ui/views/controls/menu/menu_controller.cc
index 38d35e4..cd6d3ba 100644
--- a/ui/views/controls/menu/menu_controller.cc
+++ b/ui/views/controls/menu/menu_controller.cc
@@ -2295,7 +2295,7 @@ View* MenuController::GetActiveMouseView() {
void MenuController::SetExitType(ExitType type) {
exit_type_ = type;
// Exit nested message loops as soon as possible. We do this as
- // MessageLoop::Dispatcher is only invoked before native events, which means
+ // MessagePumpDispatcher is only invoked before native events, which means
// its entirely possible for a Widget::CloseNow() task to be processed before
// the next native message. By using QuitNow() we ensures the nested message
// loop returns as soon as possible and avoids having deleted views classes
diff --git a/ui/views/controls/menu/menu_controller.h b/ui/views/controls/menu/menu_controller.h
index 6dc77fe..a834459 100644
--- a/ui/views/controls/menu/menu_controller.h
+++ b/ui/views/controls/menu/menu_controller.h
@@ -13,7 +13,7 @@
#include "base/compiler_specific.h"
#include "base/memory/scoped_ptr.h"
-#include "base/message_loop/message_loop.h"
+#include "base/message_loop/message_pump_dispatcher.h"
#include "base/timer/timer.h"
#include "ui/events/event_constants.h"
#include "ui/views/controls/menu/menu_delegate.h"
@@ -45,7 +45,7 @@ class MenuRunnerImpl;
// MenuController is used internally by the various menu classes to manage
// showing, selecting and drag/drop for menus. All relevant events are
// forwarded to the MenuController from SubmenuView and MenuHost.
-class VIEWS_EXPORT MenuController : public base::MessageLoop::Dispatcher,
+class VIEWS_EXPORT MenuController : public base::MessagePumpDispatcher,
public WidgetObserver {
public:
// Enumeration of how the menu should exit.
diff --git a/ui/views/focus/accelerator_handler.h b/ui/views/focus/accelerator_handler.h
index 29f353e..cf0a880 100644
--- a/ui/views/focus/accelerator_handler.h
+++ b/ui/views/focus/accelerator_handler.h
@@ -10,8 +10,9 @@
#include <set>
#include <vector>
+#include "base/basictypes.h"
#include "base/compiler_specific.h"
-#include "base/message_loop/message_loop.h"
+#include "base/message_loop/message_pump_dispatcher.h"
#include "ui/views/views_export.h"
namespace views {
@@ -24,7 +25,7 @@ bool VIEWS_EXPORT DispatchXEvent(XEvent* xevent);
// This class delegates the key messages to the associated FocusManager class
// for the window that is receiving these messages for accelerator processing.
-class VIEWS_EXPORT AcceleratorHandler : public base::MessageLoop::Dispatcher {
+class VIEWS_EXPORT AcceleratorHandler : public base::MessagePumpDispatcher {
public:
AcceleratorHandler();
diff --git a/ui/views/widget/desktop_aura/desktop_dispatcher_client.cc b/ui/views/widget/desktop_aura/desktop_dispatcher_client.cc
index bd4ba02..212a6a4 100644
--- a/ui/views/widget/desktop_aura/desktop_dispatcher_client.cc
+++ b/ui/views/widget/desktop_aura/desktop_dispatcher_client.cc
@@ -13,7 +13,7 @@ DesktopDispatcherClient::DesktopDispatcherClient() {}
DesktopDispatcherClient::~DesktopDispatcherClient() {}
void DesktopDispatcherClient::RunWithDispatcher(
- base::MessageLoop::Dispatcher* nested_dispatcher,
+ base::MessagePumpDispatcher* nested_dispatcher,
aura::Window* associated_window,
bool nestable_tasks_allowed) {
// TODO(erg): This class has been copypastad from
diff --git a/ui/views/widget/desktop_aura/desktop_dispatcher_client.h b/ui/views/widget/desktop_aura/desktop_dispatcher_client.h
index 5e7a517..dfc5179 100644
--- a/ui/views/widget/desktop_aura/desktop_dispatcher_client.h
+++ b/ui/views/widget/desktop_aura/desktop_dispatcher_client.h
@@ -18,7 +18,7 @@ class VIEWS_EXPORT DesktopDispatcherClient
DesktopDispatcherClient();
virtual ~DesktopDispatcherClient();
- virtual void RunWithDispatcher(base::MessageLoop::Dispatcher* dispatcher,
+ virtual void RunWithDispatcher(base::MessagePumpDispatcher* dispatcher,
aura::Window* associated_window,
bool nestable_tasks_allowed) OVERRIDE;
diff --git a/ui/views/widget/desktop_aura/desktop_root_window_host_x11.cc b/ui/views/widget/desktop_aura/desktop_root_window_host_x11.cc
index 0abccdd..9c07927 100644
--- a/ui/views/widget/desktop_aura/desktop_root_window_host_x11.cc
+++ b/ui/views/widget/desktop_aura/desktop_root_window_host_x11.cc
@@ -1225,7 +1225,7 @@ void DesktopWindowTreeHostX11::MapWindow(ui::WindowShowState show_state) {
}
////////////////////////////////////////////////////////////////////////////////
-// DesktopWindowTreeHostX11, MessageLoop::Dispatcher implementation:
+// DesktopWindowTreeHostX11, MessagePumpDispatcher implementation:
bool DesktopWindowTreeHostX11::Dispatch(const base::NativeEvent& event) {
XEvent* xev = event;
diff --git a/ui/views/widget/desktop_aura/desktop_root_window_host_x11.h b/ui/views/widget/desktop_aura/desktop_root_window_host_x11.h
index 13f22f8..9f583ed 100644
--- a/ui/views/widget/desktop_aura/desktop_root_window_host_x11.h
+++ b/ui/views/widget/desktop_aura/desktop_root_window_host_x11.h
@@ -37,7 +37,7 @@ class X11WindowEventFilter;
class VIEWS_EXPORT DesktopWindowTreeHostX11 :
public DesktopWindowTreeHost,
public aura::WindowTreeHost,
- public base::MessageLoop::Dispatcher {
+ public base::MessagePumpDispatcher {
public:
DesktopWindowTreeHostX11(
internal::NativeWidgetDelegate* native_widget_delegate,
diff --git a/ui/views/widget/desktop_aura/x11_whole_screen_move_loop.cc b/ui/views/widget/desktop_aura/x11_whole_screen_move_loop.cc
index 452a531..966a791 100644
--- a/ui/views/widget/desktop_aura/x11_whole_screen_move_loop.cc
+++ b/ui/views/widget/desktop_aura/x11_whole_screen_move_loop.cc
@@ -57,7 +57,7 @@ X11WholeScreenMoveLoop::X11WholeScreenMoveLoop(
X11WholeScreenMoveLoop::~X11WholeScreenMoveLoop() {}
////////////////////////////////////////////////////////////////////////////////
-// DesktopWindowTreeHostLinux, MessageLoop::Dispatcher implementation:
+// DesktopWindowTreeHostLinux, MessagePumpDispatcher implementation:
bool X11WholeScreenMoveLoop::Dispatch(const base::NativeEvent& event) {
XEvent* xev = event;
diff --git a/ui/aura/dispatcher_win.cc b/ui/aura/dispatcher_win.cc
index 7160dc7..63b42a2 100644
--- a/ui/aura/dispatcher_win.cc
+++ b/ui/aura/dispatcher_win.cc
@@ -4,16 +4,16 @@
#include "base/basictypes.h"
#include "base/compiler_specific.h"
-#include "base/message_loop/message_loop.h"
+#include "base/message_loop/message_pump_dispatcher.h"
namespace aura {
-class DispatcherWin : public base::MessageLoop::Dispatcher {
+class DispatcherWin : public base::MessagePumpDispatcher {
public:
DispatcherWin() {}
virtual ~DispatcherWin() {}
// Overridden from MessageLoop::Dispatcher:
virtual bool Dispatch(const base::NativeEvent& event) OVERRIDE;
private:
@@ -26,7 +26,7 @@ bool DispatcherWin::Dispatch(const base::NativeEvent& msg) {
return true;
}
-base::MessageLoop::Dispatcher* CreateDispatcher() {
+base::MessagePumpDispatcher* CreateDispatcher() {
return new DispatcherWin;
}
@@ -4,16 +4,16 @@
DispatcherWin() {}
virtual ~DispatcherWin() {}
- // Overridden from MessageLoop::Dispatcher:
+ // Overridden from MessagePumpDispatcher:
virtual bool Dispatch(const base::NativeEvent& event) OVERRIDE;
private:
diff --git a/ui/views/widget/desktop_aura/desktop_drag_drop_client_aurax11.cc b/ui/views/widget/desktop_aura/desktop_drag_drop_client_aurax11.cc
index 59e46f9..bb9a5cf 100644
--- a/ui/views/widget/desktop_aura/desktop_drag_drop_client_aurax11.cc
+++ b/ui/views/widget/desktop_aura/desktop_drag_drop_client_aurax11.cc
@@ -9,6 +9,7 @@
#include "base/event_types.h"
#include "base/lazy_instance.h"
#include "base/message_loop/message_loop.h"
+#include "base/message_loop/message_pump_dispatcher.h"
#include "ui/aura/client/drag_drop_client.h"
#include "ui/aura/client/drag_drop_delegate.h"
#include "ui/aura/root_window.h"
@@ -138,7 +139,7 @@ void FindWindowFor(const gfx::Point& screen_point,
namespace views {
class DesktopDragDropClientAuraX11::X11DragContext :
- public base::MessageLoop::Dispatcher {
+ public base::MessagePumpDispatcher {
public:
X11DragContext(ui::X11AtomCache* atom_cache,
::Window local_window,
@@ -173,7 +174,7 @@ class DesktopDragDropClientAuraX11::X11DragContext :
int GetDragOperation() const;
private:
// Overridden from MessageLoop::Dispatcher:
virtual bool Dispatch(const base::NativeEvent& event) OVERRIDE;
// The atom cache owned by our parent.
@@ -173,7 +174,7 @@ class DesktopDragDropClientAuraX11::X11DragContext :
int GetDragOperation() const;
private:
- // Overridden from MessageLoop::Dispatcher:
+ // Overridden from MessagePumpDispatcher:
virtual bool Dispatch(const base::NativeEvent& event) OVERRIDE;
// The atom cache owned by our parent.
diff --git a/ui/views/widget/desktop_aura/x11_desktop_handler.h b/ui/views/widget/desktop_aura/x11_desktop_handler.h
index b5c8bd8..933fcef 100644
--- a/ui/views/widget/desktop_aura/x11_desktop_handler.h
+++ b/ui/views/widget/desktop_aura/x11_desktop_handler.h
@@ -9,7 +9,7 @@
// Get rid of a macro from Xlib.h that conflicts with Aura's RootWindow class.
#undef RootWindow
-#include "base/message_loop/message_loop.h"
+#include "base/message_loop/message_pump_dispatcher.h"
#include "ui/aura/env_observer.h"
#include "ui/gfx/x/x11_atom_cache.h"
#include "ui/gfx/x/x11_types.h"
@@ -22,7 +22,7 @@ namespace views {
// A singleton that owns global objects related to the desktop and listens for
// X11 events on the X11 root window. Destroys itself when aura::Env is
// deleted.
-class VIEWS_EXPORT X11DesktopHandler : public base::MessageLoop::Dispatcher,
+class VIEWS_EXPORT X11DesktopHandler : public base::MessagePumpDispatcher,
public aura::EnvObserver {
public:
// Returns the singleton handler.
@@ -40,7 +40,7 @@ class VIEWS_EXPORT X11DesktopHandler : public base::MessageLoop::Dispatcher,
// dispatcher. The window dispatcher sends these events to here.
void ProcessXEvent(const base::NativeEvent& event);
// Overridden from MessageLoop::Dispatcher:
virtual bool Dispatch(const base::NativeEvent& event) OVERRIDE;
// Overridden from aura::EnvObserver:
@@ -40,7 +40,7 @@ class VIEWS_EXPORT X11DesktopHandler : public base::MessageLoop::Dispatcher,
// dispatcher. The window dispatcher sends these events to here.
void ProcessXEvent(const base::NativeEvent& event);
- // Overridden from MessageLoop::Dispatcher:
+ // Overridden from MessagePumpDispatcher:
virtual bool Dispatch(const base::NativeEvent& event) OVERRIDE;
// Overridden from aura::EnvObserver:
diff --git a/ui/views/widget/desktop_aura/x11_whole_screen_move_loop.h b/ui/views/widget/desktop_aura/x11_whole_screen_move_loop.h
index d26d66c..000ecb3 100644
--- a/ui/views/widget/desktop_aura/x11_whole_screen_move_loop.h
+++ b/ui/views/widget/desktop_aura/x11_whole_screen_move_loop.h
@@ -5,8 +5,9 @@
#ifndef UI_VIEWS_WIDGET_DESKTOP_AURA_X11_WHOLE_SCREEN_MOVE_LOOP_H_
#define UI_VIEWS_WIDGET_DESKTOP_AURA_X11_WHOLE_SCREEN_MOVE_LOOP_H_
+#include "base/callback.h"
#include "base/compiler_specific.h"
-#include "base/message_loop/message_loop.h"
+#include "base/message_loop/message_pump_dispatcher.h"
#include "ui/gfx/image/image_skia.h"
#include "ui/gfx/native_widget_types.h"
#include "ui/gfx/vector2d_f.h"
@@ -24,12 +25,12 @@ class Widget;
// Runs a nested message loop and grabs the mouse. This is used to implement
// dragging.
-class X11WholeScreenMoveLoop : public base::MessageLoop::Dispatcher {
+class X11WholeScreenMoveLoop : public base::MessagePumpDispatcher {
public:
explicit X11WholeScreenMoveLoop(X11WholeScreenMoveLoopDelegate* delegate);
virtual ~X11WholeScreenMoveLoop();
// Overridden from base::MessageLoop::Dispatcher:
virtual bool Dispatch(const base::NativeEvent& event) OVERRIDE;
// Runs the nested message loop. While the mouse is grabbed, use |cursor| as
@@ -24,12 +25,12 @@ class Widget;
explicit X11WholeScreenMoveLoop(X11WholeScreenMoveLoopDelegate* delegate);
virtual ~X11WholeScreenMoveLoop();
- // Overridden from base::MessageLoop::Dispatcher:
+ // Overridden from base::MessagePumpDispatcher:
virtual bool Dispatch(const base::NativeEvent& event) OVERRIDE;
// Runs the nested message loop. While the mouse is grabbed, use |cursor| as